@@ -8,6 +8,7 @@ import (
 type Addition struct {
 	Username string `json:"username" required:"true"`
 	Password string `json:"password" required:"true"`
+	Cookie   string `json:"cookie" help:"Fill in the cookie if need captcha"`
 	driver.RootID
 }
 
@@ -15,6 +16,7 @@ var config = driver.Config{
 	Name:        "189Cloud",
 	LocalSort:   true,
 	DefaultRoot: "-11",
+	Alert:       `info|You can try to use 189PC driver if this driver does not work.`,
 }
 
 func init() {
